==> ndla-video-search-0.2.3.tgz: package/es/VideoSearch.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import BEMHelper from 'react-bem-helper';
import { Pager } from 'ndla-ui';
import VideoSearchForm from './VideoSearchForm';
import VideoSearchList from './VideoSearchList';
import VideoLoadMoreButton from './VideoLoadMoreButton';
import VideoTabs from './VideoTabs';
import { getLastPage } from './videoHelpers';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

var VideoSearch = function (_React$Component) {
  _inherits(VideoSearch, _React$Component);

  function VideoSearch() {
    _classCallCheck(this, VideoSearch);

    var _this = _possibleConstructorReturn(this, (VideoSearch.__proto__ || Object.getPrototypeOf(VideoSearch)).call(this));

    _this.state = {
      queryObject: {
        query: '',
        offset: 0,
        limit: 10
      },
      videos: [],
      selectedType: 'brightcove', // Default
      selectedVideo: undefined,
      lastPage: 0,
      searching: false
    };

    _this.submitVideoSearchQuery = _this.submitVideoSearchQuery.bind(_this);
    _this.changeQueryPage = _this.changeQueryPage.bind(_this);
    _this.onSearchTypeChange = _this.onSearchTypeChange.bind(_this);
    _this.searchVideos = _this.searchVideos.bind(_this);
    _this.onVideoPreview = _this.onVideoPreview.bind(_this);
    _this.onSelectVideo = _this.onSelectVideo.bind(_this);
    _this.loadMoreVideos = _this.loadMoreVideos.bind(_this);
    return _this;
  }

  _createClass(VideoSearch, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.searchVideos(this.state.queryObject);
    }
  }, {
    key: 'onVideoPreview',
    value: function onVideoPreview(video) {
      this.setState({ selectedVideo: video });
    }
  }, {
    key: 'onSelectVideo',
    value: function onSelectVideo(video) {
      var selectedType = this.state.selectedType;
      var onVideoSelect = this.props.onVideoSelect;

      this.setState({ selectedVideo: undefined });
      onVideoSelect(video, selectedType);
    }
  }, {
    key: 'onSearchTypeChange',
    value: function onSearchTypeChange(type) {
      var queryObject = void 0;
      if (type === 'youtube') {
        queryObject = {
          query: '',
          offset: undefined,
          limit: undefined,
          page: 1,
          start: 1
        };
      } else {
        queryObject = {
          query: '',
          offset: 0,
          limit: 10,
          page: undefined,
          start: undefined
        };
      }

      this.setState({
        queryObject: queryObject,
        selectedType: type,
        selectedVideo: undefined
      }, this.searchVideos(queryObject, type));
    }
  }, {
    key: 'loadMoreVideos',
    value: function loadMoreVideos() {
      var _this2 = this;

      var _state = this.state,
          queryObject = _state.queryObject,
          videos = _state.videos,
          selectedType = _state.selectedType;
      var _props = this.props,
          searchVideos = _props.searchVideos,
          onError = _props.onError;

      this.setState({ searching: true });
      searchVideos(_extends({}, queryObject, {
        offset: queryObject.offset + 10
      }), selectedType).then(function (result) {
        _this2.setState(function (prevState) {
          return {
            queryObject: _extends({}, prevState.queryObject, {
              offset: prevState.queryObject.offset + 10
            }),
            videos: videos.concat(result),
            searching: false
          };
        });
      }).catch(function (err) {
        onError(err);
        _this2.setState({ searching: false });
      });
    }
  }, {
    key: 'changeQueryPage',
    value: function changeQueryPage(page) {
      this.setState({ lastPage: 0 });
      var queryObject = this.state.queryObject;

      var nextIndex = queryObject.start + (page.page - queryObject.page) * 10;
      var newQueryObject = _extends({}, queryObject, page, { start: nextIndex });
      this.searchVideos(newQueryObject);
    }
  }, {
    key: 'submitVideoSearchQuery',
    value: function submitVideoSearchQuery(query) {
      var queryObject = _extends({}, this.state.queryObject, { query: query });
      this.searchVideos(queryObject);
    }
  }, {
    key: 'searchVideos',
    value: function searchVideos(queryObject) {
      var _this3 = this;

      var selectedType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state.selectedType;
      var _props2 = this.props,
          searchVideos = _props2.searchVideos,
          onError = _props2.onError;

      this.setState({ searching: true, videos: [] });
      searchVideos(queryObject, selectedType).then(function (result) {
        _this3.setState(function (prevState) {
          return {
            queryObject: _extends({}, prevState.queryObject, {
              query: queryObject.query,
              page: queryObject.page,
              start: queryObject.start,
              offset: 0
            }),
            videos: selectedType === 'youtube' ? result.items : result,
            searching: false,
            lastPage: getLastPage(result, selectedType)
          };
        });
      }).catch(function (err) {
        onError(err);
        _this3.setState({ searching: false });
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var _this4 = this;

      var _props3 = this.props,
          translations = _props3.translations,
          locale = _props3.locale,
          enabledSources = _props3.enabledSources;
      var _state2 = this.state,
          queryObject = _state2.queryObject,
          lastPage = _state2.lastPage,
          videos = _state2.videos,
          selectedVideo = _state2.selectedVideo,
          selectedType = _state2.selectedType,
          searching = _state2.searching;
      var query = queryObject.query,
          page = queryObject.page;


      var paginationItem = function paginationItem() {
        if (selectedType === 'brightcove') {
          return React.createElement(VideoLoadMoreButton, {
            searching: searching,
            videos: videos,
            loadMoreVideos: _this4.loadMoreVideos,
            limit: queryObject.limit,
            translations: translations
          });
        }
        return React.createElement(Pager, {
          page: page || 1,
          lastPage: lastPage,
          onClick: _this4.changeQueryPage
        });
      };

      var searchListTabs = enabledSources.map(function (source) {
        return {
          title: source,
          content: React.createElement(
            'div',
            classes('list'),
            React.createElement(VideoSearchList, {
              translations: translations,
              selectedType: source.toLowerCase(),
              selectedVideo: selectedVideo,
              videos: videos,
              locale: locale,
              onVideoPreview: _this4.onVideoPreview,
              searching: searching,
              onSelectVideo: _this4.onSelectVideo
            })
          )
        };
      });

      return React.createElement(
        'div',
        classes(),
        React.createElement(VideoSearchForm, {
          onSearchQuerySubmit: this.submitVideoSearchQuery,
          query: query,
          searching: searching,
          translations: translations
        }),
        React.createElement(VideoTabs, {
          searchTypes: selectedType,
          tabs: searchListTabs,
          onSearchTypeChange: this.onSearchTypeChange
        }),
        paginationItem()
      );
    }
  }]);

  return VideoSearch;
}(React.Component);

VideoSearch.propTypes = {
  onVideoSelect: PropTypes.func.isRequired,
  searchVideos: PropTypes.func.isRequired,
  onError: PropTypes.func.isRequired,
  translations: PropTypes.shape({
    searchPlaceholder: PropTypes.string.isRequired,
    searchButtonTitle: PropTypes.string.isRequired,
    loadMoreVideos: PropTypes.string.isRequired
  }),
  locale: PropTypes.string.isRequired,
  enabledSources: PropTypes.array
};

VideoSearch.defaultProps = {
  enabledSources: ['Brightcove']
};

export default VideoSearch;

==> ndla-video-search-0.5.0-0.tgz: package/es/VideoSearch.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import BEMHelper from 'react-bem-helper';
import Pager from 'ndla-pager';
import VideoSearchForm from './VideoSearchForm';
import VideoSearchList from './VideoSearchList';
import VideoLoadMoreButton from './VideoLoadMoreButton';
import VideoTabs from './VideoTabs';
import { getLastPage } from './videoHelpers';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

var VideoSearch = function (_React$Component) {
  _inherits(VideoSearch, _React$Component);

  function VideoSearch() {
    _classCallCheck(this, VideoSearch);

    var _this = _possibleConstructorReturn(this, (VideoSearch.__proto__ || Object.getPrototypeOf(VideoSearch)).call(this));

    _this.state = {
      queryObject: {
        query: '',
        offset: 0,
        limit: 10
      },
      videos: [],
      selectedType: 'brightcove', // Default
      selectedVideo: undefined,
      lastPage: 0,
      searching: false
    };

    _this.submitVideoSearchQuery = _this.submitVideoSearchQuery.bind(_this);
    _this.changeQueryPage = _this.changeQueryPage.bind(_this);
    _this.onSearchTypeChange = _this.onSearchTypeChange.bind(_this);
    _this.searchVideos = _this.searchVideos.bind(_this);
    _this.onVideoPreview = _this.onVideoPreview.bind(_this);
    _this.onSelectVideo = _this.onSelectVideo.bind(_this);
    _this.loadMoreVideos = _this.loadMoreVideos.bind(_this);
    return _this;
  }

  _createClass(VideoSearch, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.searchVideos(this.state.queryObject);
    }
  }, {
    key: 'onVideoPreview',
    value: function onVideoPreview(video) {
      this.setState({ selectedVideo: video });
    }
  }, {
    key: 'onSelectVideo',
    value: function onSelectVideo(video) {
      var selectedType = this.state.selectedType;
      var onVideoSelect = this.props.onVideoSelect;

      this.setState({ selectedVideo: undefined });
      onVideoSelect(video, selectedType);
    }
  }, {
    key: 'onSearchTypeChange',
    value: function onSearchTypeChange(type) {
      var queryObject = void 0;
      if (type === 'youtube') {
        queryObject = {
          query: '',
          offset: undefined,
          limit: undefined,
          page: 1,
          start: 1
        };
      } else {
        queryObject = {
          query: '',
          offset: 0,
          limit: 10,
          page: undefined,
          start: undefined
        };
      }

      this.setState({
        queryObject: queryObject,
        selectedType: type,
        selectedVideo: undefined
      }, this.searchVideos(queryObject, type));
    }
  }, {
    key: 'loadMoreVideos',
    value: function loadMoreVideos() {
      var _this2 = this;

      var _state = this.state,
          queryObject = _state.queryObject,
          videos = _state.videos,
          selectedType = _state.selectedType;
      var _props = this.props,
          searchVideos = _props.searchVideos,
          onError = _props.onError;

      this.setState({ searching: true });
      searchVideos(_extends({}, queryObject, {
        offset: queryObject.offset + 10
      }), selectedType).then(function (result) {
        _this2.setState(function (prevState) {
          return {
            queryObject: _extends({}, prevState.queryObject, {
              offset: prevState.queryObject.offset + 10
            }),
            videos: videos.concat(result),
            searching: false
          };
        });
      }).catch(function (err) {
        onError(err);
        _this2.setState({ searching: false });
      });
    }
  }, {
    key: 'changeQueryPage',
    value: function changeQueryPage(page) {
      this.setState({ lastPage: 0 });
      var queryObject = this.state.queryObject;

      var nextIndex = queryObject.start + (page.page - queryObject.page) * 10;
      var newQueryObject = _extends({}, queryObject, page, { start: nextIndex });
      this.searchVideos(newQueryObject);
    }
  }, {
    key: 'submitVideoSearchQuery',
    value: function submitVideoSearchQuery(query) {
      var queryObject = _extends({}, this.state.queryObject, { query: query });
      this.searchVideos(queryObject);
    }
  }, {
    key: 'searchVideos',
    value: function searchVideos(queryObject) {
      var _this3 = this;

      var selectedType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.state.selectedType;
      var _props2 = this.props,
          searchVideos = _props2.searchVideos,
          onError = _props2.onError;

      this.setState({ searching: true, videos: [] });
      searchVideos(queryObject, selectedType).then(function (result) {
        _this3.setState(function (prevState) {
          return {
            queryObject: _extends({}, prevState.queryObject, {
              query: queryObject.query,
              page: queryObject.page,
              start: queryObject.start,
              offset: 0
            }),
            videos: selectedType === 'youtube' ? result.items : result,
            searching: false,
            lastPage: getLastPage(result, selectedType)
          };
        });
      }).catch(function (err) {
        onError(err);
        _this3.setState({ searching: false });
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var _this4 = this;

      var _props3 = this.props,
          translations = _props3.translations,
          locale = _props3.locale,
          enabledSources = _props3.enabledSources;
      var _state2 = this.state,
          queryObject = _state2.queryObject,
          lastPage = _state2.lastPage,
          videos = _state2.videos,
          selectedVideo = _state2.selectedVideo,
          selectedType = _state2.selectedType,
          searching = _state2.searching;
      var query = queryObject.query,
          page = queryObject.page;


      var paginationItem = function paginationItem() {
        if (selectedType === 'brightcove') {
          return React.createElement(VideoLoadMoreButton, {
            searching: searching,
            videos: videos,
            loadMoreVideos: _this4.loadMoreVideos,
            limit: queryObject.limit,
            translations: translations
          });
        }
        return React.createElement(Pager, {
          page: page || 1,
          lastPage: lastPage,
          onClick: _this4.changeQueryPage
        });
      };

      var searchListTabs = enabledSources.map(function (source) {
        return {
          title: source,
          content: React.createElement(
            'div',
            classes('list'),
            React.createElement(VideoSearchList, {
              translations: translations,
              selectedType: source.toLowerCase(),
              selectedVideo: selectedVideo,
              videos: videos,
              locale: locale,
              onVideoPreview: _this4.onVideoPreview,
              searching: searching,
              onSelectVideo: _this4.onSelectVideo
            })
          )
        };
      });

      return React.createElement(
        'div',
        classes(),
        React.createElement(VideoSearchForm, {
          onSearchQuerySubmit: this.submitVideoSearchQuery,
          query: query,
          searching: searching,
          translations: translations
        }),
        React.createElement(VideoTabs, {
          searchTypes: selectedType,
          tabs: searchListTabs,
          onSearchTypeChange: this.onSearchTypeChange
        }),
        paginationItem()
      );
    }
  }]);

  return VideoSearch;
}(React.Component);

VideoSearch.propTypes = {
  onVideoSelect: PropTypes.func.isRequired,
  searchVideos: PropTypes.func.isRequired,
  onError: PropTypes.func.isRequired,
  translations: PropTypes.shape({
    searchPlaceholder: PropTypes.string.isRequired,
    searchButtonTitle: PropTypes.string.isRequired,
    loadMoreVideos: PropTypes.string.isRequired
  }),
  locale: PropTypes.string.isRequired,
  enabledSources: PropTypes.arrayOf(PropTypes.string)
};

VideoSearch.defaultProps = {
  enabledSources: ['Brightcove']
};

export default VideoSearch;
